@@ -27,9 +27,13 @@ else:
 __all__ = (
     "BlockTypeDef",
     "ChangedBlockTypeDef",
+    "TagTypeDef",
+    "CompleteSnapshotResponseTypeDef",
     "GetSnapshotBlockResponseTypeDef",
     "ListChangedBlocksResponseTypeDef",
     "ListSnapshotBlocksResponseTypeDef",
+    "PutSnapshotBlockResponseTypeDef",
+    "StartSnapshotResponseTypeDef",
 )
 
 BlockTypeDef = TypedDict("BlockTypeDef", {"BlockIndex": int, "BlockToken": str}, total=False)
@@ -40,6 +44,14 @@ ChangedBlockTypeDef = TypedDict(
     total=False,
 )
 
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
+CompleteSnapshotResponseTypeDef = TypedDict(
+    "CompleteSnapshotResponseTypeDef",
+    {"Status": Literal["completed", "pending", "error"]},
+    total=False,
+)
+
 GetSnapshotBlockResponseTypeDef = TypedDict(
     "GetSnapshotBlockResponseTypeDef",
     {
@@ -74,3 +86,26 @@ ListSnapshotBlocksResponseTypeDef = TypedDict(
     },
     total=False,
 )
+
+PutSnapshotBlockResponseTypeDef = TypedDict(
+    "PutSnapshotBlockResponseTypeDef",
+    {"Checksum": str, "ChecksumAlgorithm": Literal["SHA256"]},
+    total=False,
+)
+
+StartSnapshotResponseTypeDef = TypedDict(
+    "StartSnapshotResponseTypeDef",
+    {
+        "Description": str,
+        "SnapshotId": str,
+        "OwnerId": str,
+        "Status": Literal["completed", "pending", "error"],
+        "StartTime": datetime,
+        "VolumeSize": int,
+        "BlockSize": int,
+        "Tags": List["TagTypeDef"],
+        "ParentSnapshotId": str,
+        "KmsKeyArn": str,
+    },
+    total=False,
+)
